@@ -13,7 +13,7 @@ class Image:
         self.process()
 
     @classmethod
-    def fromPath(cls, filename):
+    def fromPath(cls, path):
         data = Image.seek(path)
         return cls(data)  
 
